@@ -177,6 +177,8 @@ import jsii
 import publication
 import typing_extensions
 
+from typeguard import check_type
+
 from ._jsii import *
 
 import aws_cdk.aws_dynamodb
@@ -195,10 +197,10 @@ class IotToLambdaToDynamoDB(
         scope: aws_cdk.core.Construct,
         id: builtins.str,
         *,
-        iot_topic_rule_props: aws_cdk.aws_iot.CfnTopicRuleProps,
-        dynamo_table_props: typing.Optional[aws_cdk.aws_dynamodb.TableProps] = None,
+        iot_topic_rule_props: typing.Union[aws_cdk.aws_iot.CfnTopicRuleProps, typing.Dict[str, typing.Any]],
+        dynamo_table_props: typing.Optional[typing.Union[aws_cdk.aws_dynamodb.TableProps, typing.Dict[str, typing.Any]]] = None,
         existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
-        lambda_function_props: typing.Optional[aws_cdk.aws_lambda.FunctionProps] = None,
+        lambda_function_props: typing.Optional[typing.Union[aws_cdk.aws_lambda.FunctionProps, typing.Dict[str, typing.Any]]] = None,
         table_permissions: typing.Optional[builtins.str] = None,
     ) -> None:
         '''
@@ -214,6 +216,10 @@ class IotToLambdaToDynamoDB(
         :since: 0.8.0
         :summary: Constructs a new instance of the IotToLambdaToDynamoDB class.
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(IotToLambdaToDynamoDB.__init__)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = IotToLambdaToDynamoDBProps(
             iot_topic_rule_props=iot_topic_rule_props,
             dynamo_table_props=dynamo_table_props,
@@ -255,10 +261,10 @@ class IotToLambdaToDynamoDBProps:
     def __init__(
         self,
         *,
-        iot_topic_rule_props: aws_cdk.aws_iot.CfnTopicRuleProps,
-        dynamo_table_props: typing.Optional[aws_cdk.aws_dynamodb.TableProps] = None,
+        iot_topic_rule_props: typing.Union[aws_cdk.aws_iot.CfnTopicRuleProps, typing.Dict[str, typing.Any]],
+        dynamo_table_props: typing.Optional[typing.Union[aws_cdk.aws_dynamodb.TableProps, typing.Dict[str, typing.Any]]] = None,
         existing_lambda_obj: typing.Optional[aws_cdk.aws_lambda.Function] = None,
-        lambda_function_props: typing.Optional[aws_cdk.aws_lambda.FunctionProps] = None,
+        lambda_function_props: typing.Optional[typing.Union[aws_cdk.aws_lambda.FunctionProps, typing.Dict[str, typing.Any]]] = None,
         table_permissions: typing.Optional[builtins.str] = None,
     ) -> None:
         '''
@@ -276,6 +282,13 @@ class IotToLambdaToDynamoDBProps:
             dynamo_table_props = aws_cdk.aws_dynamodb.TableProps(**dynamo_table_props)
         if isinstance(lambda_function_props, dict):
             lambda_function_props = aws_cdk.aws_lambda.FunctionProps(**lambda_function_props)
+        if __debug__:
+            type_hints = typing.get_type_hints(IotToLambdaToDynamoDBProps.__init__)
+            check_type(argname="argument iot_topic_rule_props", value=iot_topic_rule_props, expected_type=type_hints["iot_topic_rule_props"])
+            check_type(argname="argument dynamo_table_props", value=dynamo_table_props, expected_type=type_hints["dynamo_table_props"])
+            check_type(argname="argument existing_lambda_obj", value=existing_lambda_obj, expected_type=type_hints["existing_lambda_obj"])
+            check_type(argname="argument lambda_function_props", value=lambda_function_props, expected_type=type_hints["lambda_function_props"])
+            check_type(argname="argument table_permissions", value=table_permissions, expected_type=type_hints["table_permissions"])
         self._values: typing.Dict[str, typing.Any] = {
             "iot_topic_rule_props": iot_topic_rule_props,
         }
